@@ -9,9 +9,9 @@
 #ifndef KDNSSDREMOTESERVICE_H
 #define KDNSSDREMOTESERVICE_H
 
-#include <QObject>
+#include "servicebase.h"
 #include <QMetaType>
-#include <dnssd/servicebase.h>
+#include <QObject>
 
 namespace KDNSSD
 {
@@ -116,9 +116,9 @@ Q_SIGNALS:
 
 protected:
     void virtual_hook(int id, void *data) override;
+
 private:
     friend class RemoteServicePrivate;
-
 };
 
 }
